import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.tree.*;
import javax.swing.event.*;
/**
 * Trida GUI která zobrazí pomocí stromu (JTree) organizační strukturu
 *
 * @author     Luboš Pavlíček
 * @version    1.0, říjen 2006
 */
public class GUI {

    private JFrame okno;
    private JTree strom;
    private IUtvar koren;
    
    /**
     * Konstruktor pro grafickou třídu zobrazují organizační strukturu pomocí
     * stromu. Pro zobrazení stromu je potřeba zavolat metodu setVisible.
     *
     * @param  koren   kořenový útvar, od kterého se má začít zobrazovat
     */
    public GUI(IUtvar koren) {
        this.koren = koren;
        okno = new JFrame("Organizační struktura");
        strom = new JTree(new ModelStromu());
        okno.add(new JScrollPane(strom));
        okno.setSize(200,500);
    }

    /**
     * Metoda k zobrazení stromové struktury na obrazovce.
     * 
     * @param  visible  pokud true, zobrazí se okno na obrazovce.
     */
    public void setVisible(boolean visible) {
        okno.setVisible(visible);
    }
    
    /**
     * Vnitřní třída, která zajišťuje komunikaci mezi JTree a vlastní organizační
     * strukturou (viz návrhový vzor Adapter). Tato třída implementuje metody
     * z rozhraní TreeModel - jejich popis viz popis rozhraní TreeModel.
     */
    private class ModelStromu implements TreeModel {
        public Object getRoot() {
            return koren;
        }
        public Object getChild(Object parent, int index) {
            if (parent instanceof IUtvar) {
                IUtvar utvar = (IUtvar)parent;
                if (index < utvar.podrizeneUtvary().size()) {
                    return utvar.podrizeneUtvary().get(index);
                }
                else {
                    return utvar.osoby().get(index - utvar.podrizeneUtvary().size());
                }
            }
            else {
                return null;  // toto by nikdy nemelo nastat
            }
        }
        public int getChildCount(Object parent) {
            if (parent instanceof Osoba) {
                return 0;
            }
            IUtvar utvar = (IUtvar)parent;
            java.util.List <IUtvar> podrizene = utvar.podrizeneUtvary();
            java.util.List <Osoba> osoby = utvar.osoby();
            if (podrizene == null || osoby == null) {
                return 0;
            }
            else {
                return podrizene.size()+osoby.size();
            }
        }
        public boolean isLeaf(Object node) {
            return !(node instanceof IUtvar);
        }
        public void valueForPathChanged(TreePath path, Object newValue) {
        }
        public int getIndexOfChild(Object parent, Object child) {
            if (parent == null || child == null) {
                return -1;
            }
            IUtvar utvar = (IUtvar)parent;
            if (child instanceof IUtvar) {
                IUtvar clen = (IUtvar)child;
                return utvar.podrizeneUtvary().indexOf(clen);
            }
            else {
                Osoba osoba = (Osoba)child;
                return utvar.podrizeneUtvary().size()+utvar.osoby().indexOf(osoba);
            }
        }
        public void addTreeModelListener(TreeModelListener l) {
        }
        public void removeTreeModelListener(TreeModelListener l) {
        }
        
    }
}
